Slider
===========================

.. currentmodule:: enaml.widgets.slider

.. autoclass:: Slider


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_slider.QtSlider
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_slider.QtSlider

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_slider.WXSlider
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_slider.WXSlider
